<?
/********************************************************************
 * NotFTP 
 * Copyright (c) 2002, 2003 by Ryan Grove <ryan@wonko.com>
 * All rights reserved.
 *
 * This script is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA  02111-1307  USA
 ********************************************************************/

########################################################################
# Language Settings
###################

# Default language for the site. This should be specified in the form of
# a standard two-letter language abbreviation (i.e., "en" for English,
# "es" for Espaol, etc.
define("DEFAULTLANG", "en");

# Default style for the site.
define("DEFAULTSTYLE", "simple");


########################################################################
# FTP Settings
##############

# Port NotFTP should try to connect to by default. Most FTP servers run on
# port 21.
define("DEFAULTPORT", 21);

# Absolute path where FTP files should be temporarily downloaded (must
# be chmod 777'd.) The path should NOT have a trailing slash. (Note: If
# you turn on passthru downloading below, then this setting isn't 
# necessary.)
#
# It should look like this: "/path/to/file/dir"
# NOT this: "/path/to/file/dir/"
define("FILEPATH", "/path/to/file/dir");

# Set this to true to turn passthru downloading on. Passthru downloading
# opens a file pointer directly to the file a user requests from an FTP
# server and sends data to the user immediately. This is faster than
# downloading the file and then sending it to the user. The disadvantage
# is that it requires that the FTP server support passive mode. If you
# have trouble connecting to servers, set this to false.
define("PASSTHRUDOWNLOAD", true);

# Set this to true to turn passive mode on. In passive mode, data
# connections are initiated by the client, not the FTP server. This is
# only necessary if the computer running NotFTP is behind a firewall or
# NAT. However, if the FTP server is also behind a firewall, passive
# connections will most likely fail. NotFTP will try to recover
# gracefully from a failure, but connections to some servers may hang.
define("PASVMODE", false);


########################################################################
# Security Settings
###################

# Set this to true to allow users to specify what port NotFTP should
# connect to for their session.
define("ALLOWUSERPORT", false);

# Set this to true to allow users to connect to servers on your internal
# LAN (if one exists). Please note that enabling this opens up your internal
# network to anyone who has access to NotFTP, and this could be a serious
# security risk.
define("ALLOWLANSERVER", false);

# Maximum size (in bytes) of files users are allowed to upload/download.
# Note that if this is larger than the TRANSFERQUOTA value below,
# the quota value will take precedence. Set to 0 for no limit (default).
define("SIZELIMIT", 0);

# Number of files each user can transfer per day. After reaching this
# number, they won't be able to transfer anymore until 24 hours have
# passed. This just uses a simple cookie, so it's not very secure.
# Don't trust it with your life or anything. Set to 0 for no limit.
define("TRANSFERLIMIT", 0);

# Number of bytes each user can transfer per day. After reaching this
# limit, they won't be able to transfer anymore until 24 hours have
# passed. Like the TRANSFERLIMIT setting above, this uses a simple
# cookie and won't stand up to the circumvention efforts of a person
# with brains. Set to 0 for no limit. Default is 10485760 (10 megs)
define("TRANSFERQUOTA", 10485760);

# Set this to true if you only want users to be able to connect to a list
# of servers you specify. Don't forget to create the list below.
define("USESERVERLIST", false);

# List of servers and ports users are allowed to connect to if
# USESERVERLIST is true. If USESERVERLIST is false, this list will be
# ignored.
$servers[]	= array("localhost", 		21);
$servers[]	= array("ftp.kernel.org", 	21);
$servers[]	= array("ftp.freebsd.org", 	21);


########################################################################
# Other Settings
################

# Number of seconds the FTP script will run before timing out. Set this
# to zero if you want the script to run indefinitely (not recommended)
define("TIMEOUT", 120);




#########################################################################
# List of available styles and their stylesheets
#########################################################################

$styles["beveled"]["file"]		= "beveled.css";
$styles["beveled"]["name"]		= "Beveled";
$styles["beveled"]["shortname"]	= "beveled";

$styles["simple"]["file"]		= "simple.css";
$styles["simple"]["name"]		= "Simple";
$styles["simple"]["shortname"]	= "simple";

$styles["tooblue"]["file"]		= "tooblue.css";
$styles["tooblue"]["name"]		= "Too Blue";		
$styles["tooblue"]["shortname"]	= "tooblue";

#########################################################################
# List of available languages and their language files
#########################################################################

$languages["en"]["file"] = "en.php";
$languages["en"]["name"] = "English";
$languages["en"]["abbr"] = "en";

$languages["es"]["file"] = "es.php";
$languages["es"]["name"] = "Espa&ntilde;ol";
$languages["es"]["abbr"] = "es";

$languages["fr"]["file"] = "fr.php";
$languages["fr"]["name"] = "Fran&ccedil;ais";
$languages["fr"]["abbr"] = "fr";

#########################################################################
# This is where we define our MIME types. You probably don't want to
# mess with this.
#########################################################################

$mimetypes = array();
$mimetypes["application/andrew-inset"] 			= "ez";
$mimetypes["application/mac-binhex40"] 			= "hqx";
$mimetypes["application/mac-compactpro"]		= "cpt";
$mimetypes["application/msword"]				= "doc";
$mimetypes["application/octet-stream"] 			= "bin dms lha lzh exe class so dll";
$mimetypes["application/oda"] 					= "oda";
$mimetypes["application/pdf"] 					= "pdf";
$mimetypes["application/postscript"] 			= "ai eps ps";
$mimetypes["application/smil"] 					= "smi smil";
$mimetypes["application/vnd.mif"] 				= "mif";
$mimetypes["application/vnd.ms-excel"] 			= "xls";
$mimetypes["application/vnd.ms-powerpoint"] 	= "ppt";
$mimetypes["application/vnd.wap.wbxml"] 		= "wbxml";
$mimetypes["application/vnd.wap.wmlc"] 			= "wmlc";
$mimetypes["application/vnd.wap.wmlscriptc"] 	= "wmlsc";
$mimetypes["application/x-bcpio"] 				= "bcpio";
$mimetypes["application/x-cdlink"] 				= "vcd";
$mimetypes["application/x-chess-pgn"] 			= "pgn";
$mimetypes["application/x-cpio"] 				= "cpio";
$mimetypes["application/x-csh"] 				= "csh";
$mimetypes["application/x-director"] 			= "dcr dir dxr";
$mimetypes["application/x-dvi"] 				= "dvi";
$mimetypes["application/x-futuresplash"] 		= "spl";
$mimetypes["application/x-gtar"] 				= "gtar";
$mimetypes["application/x-hdf"] 				= "hdf";
$mimetypes["application/x-javascript"] 			= "js";
$mimetypes["application/x-koan"] 				= "skp skd skt skm";
$mimetypes["application/x-latex"] 				= "latex";
$mimetypes["application/x-netcdf"] 				= "nc cdf";
$mimetypes["application/x-sh"] 					= "sh";
$mimetypes["application/x-shar"] 				= "shar";
$mimetypes["application/x-shockwave-flash"] 	= "swf";
$mimetypes["application/x-stuffit"] 			= "sit";
$mimetypes["application/x-sv4cpio"] 			= "sv4cpio";
$mimetypes["application/x-sv4crc"] 				= "sv4crc";
$mimetypes["application/x-tar"] 				= "tar";
$mimetypes["application/x-tcl"] 				= "tcl";
$mimetypes["application/x-tex"] 				= "tex";
$mimetypes["application/x-texinfo"] 			= "texinfo texi";
$mimetypes["application/x-troff"] 				= "t tr roff";
$mimetypes["application/x-troff-man"] 			= "man";
$mimetypes["application/x-troff-me"] 			= "me";
$mimetypes["application/x-troff-ms"] 			= "ms";
$mimetypes["application/x-ustar"] 				= "ustar";
$mimetypes["application/x-wais-source"] 		= "src";
$mimetypes["application/zip"] 					= "zip";
$mimetypes["audio/basic"] 						= "au snd";
$mimetypes["audio/midi"] 						= "mid midi kar";
$mimetypes["audio/mpeg"] 						= "mpga mp2 mp3";
$mimetypes["audio/x-aiff"] 						= "aif aiff aifc";
$mimetypes["audio/x-mpegurl"] 					= "m3u";
$mimetypes["audio/x-pn-realaudio"] 				= "ram rm";
$mimetypes["audio/x-pn-realaudio-plugin"] 		= "rpm";
$mimetypes["audio/x-realaudio"] 				= "ra";	
$mimetypes["audio/x-wav"] 						= "wav";
$mimetypes["chemical/x-pdb"] 					= "pdb";
$mimetypes["chemical/x-xyz"] 					= "xyz";
$mimetypes["image/bmp"] 						= "bmp";
$mimetypes["image/gif"] 						= "gif";
$mimetypes["image/ief"] 						= "ief";
$mimetypes["image/jpeg"] 						= "jpeg jpg jpe";
$mimetypes["image/png"] 						= "png";
$mimetypes["image/tiff"] 						= "tiff tif";
$mimetypes["image/vnd.wap.wbmp"] 				= "wbmp";
$mimetypes["image/x-cmu-raster"] 				= "ras";
$mimetypes["image/x-portable-anymap"] 			= "pnm";
$mimetypes["image/x-portable-bitmap"] 			= "pbm";
$mimetypes["image/x-portable-graymap"] 			= "pgm";
$mimetypes["image/x-portable-pixmap"] 			= "ppm";
$mimetypes["image/x-rgb"] 						= "rgb";
$mimetypes["image/x-xbitmap"] 					= "xbm";
$mimetypes["image/x-xpixmap"] 					= "xpm";
$mimetypes["image/x-xwindowdump"] 				= "xwd";
$mimetypes["model/iges"] 						= "igs iges";
$mimetypes["model/mesh"] 						= "msh mesh silo";
$mimetypes["model/vrml"] 						= "wrl vrml";
$mimetypes["text/css"] 							= "css";
$mimetypes["text/html"] 						= "html htm";
$mimetypes["text/plain"] 						= "asc txt";
$mimetypes["text/richtext"] 					= "rtx";
$mimetypes["text/rtf"] 							= "rtf";
$mimetypes["text/sgml"] 						= "sgml sgm";
$mimetypes["text/tab-separated-values"] 		= "tsv";
$mimetypes["text/vnd.wap.wml"] 					= "wml";
$mimetypes["text/vnd.wap.wmlscript"] 			= "wmls";
$mimetypes["text/x-setext"] 					= "etx";
$mimetypes["text/xml"] 							= "xml xsl";
$mimetypes["video/mpeg"]						= "mpeg mpg mpe";
$mimetypes["video/quicktime"] 					= "qt mov";
$mimetypes["video/vnd.mpegurl"] 				= "mxu";
$mimetypes["video/x-msvideo"] 					= "avi";
$mimetypes["video/x-sgi-movie"] 				= "movie";
$mimetypes["x-conference/x-cooltalk"] 			= "ice";

#########################################################################
# This is where we decide what language to use. Don't mess with this
# either.
#########################################################################

if (isset($newlang))
{
	require_once("lib/lang/".$languages[$newlang]["file"]);
}
elseif (isset($_COOKIE["notftplang"]))
{
	require_once("lib/lang/".$languages[$_COOKIE["notftplang"]]["file"]);
}
else
{
	require_once("lib/lang/".$languages[DEFAULTLANG]["file"]);
}

# NotFTP version. Changing this would be silly. So don't.
define("MYVERSION", "1.3.1");
?>